==> cheq-sst-kotlin-0.1.1-sources.jar: ai/cheq/sst/android/core/domain/Data.kt <==
package ai.cheq.sst.android.core.domain

import ai.cheq.sst.android.core.Config
import ai.cheq.sst.android.core.models.Models
import com.fasterxml.jackson.annotation.JsonAutoDetect
import com.fasterxml.jackson.annotation.JsonCreator
import com.fasterxml.jackson.annotation.JsonProperty

private typealias SstEvent = ai.cheq.sst.android.core.Event

@JsonAutoDetect(
    fieldVisibility = JsonAutoDetect.Visibility.NONE,
    setterVisibility = JsonAutoDetect.Visibility.NONE,
    getterVisibility = JsonAutoDetect.Visibility.NONE,
    isGetterVisibility = JsonAutoDetect.Visibility.NONE,
    creatorVisibility = JsonAutoDetect.Visibility.NONE
)
internal class Data {
    constructor(
        config: Config, event: SstEvent, models: Models.Data, dataLayer: Map<String, String?>
    ) : this(
        Settings(config),
        VirtualBrowser(models),
        DataLayer(models, config.dataLayerName, dataLayer),
        listOf(Event(config, event))
    )

    @JsonCreator
    constructor(
        settings: Settings = Settings(),
        virtualBrowser: VirtualBrowser = VirtualBrowser(),
        dataLayer: DataLayer,
        events: List<Event> = emptyList()
    ) {
        this.settings = settings
        this.virtualBrowser = virtualBrowser
        this.dataLayer = dataLayer
        this.events = events
    }

    @JsonProperty
    val settings: Settings

    @JsonProperty
    val virtualBrowser: VirtualBrowser

    @JsonProperty
    val dataLayer: DataLayer

    @JsonProperty
    val events: List<Event>
}

==> cheq-sst-kotlin-0.2.2-sources.jar: ai/cheq/sst/android/core/domain/Data.kt <==
package ai.cheq.sst.android.core.domain

import ai.cheq.sst.android.core.Config
import ai.cheq.sst.android.core.models.Models
import com.fasterxml.jackson.annotation.JsonAutoDetect
import com.fasterxml.jackson.annotation.JsonCreator
import com.fasterxml.jackson.annotation.JsonInclude
import com.fasterxml.jackson.annotation.JsonProperty
import java.util.Locale

private typealias SstEvent = ai.cheq.sst.android.core.Event

@JsonAutoDetect(
    fieldVisibility = JsonAutoDetect.Visibility.NONE,
    setterVisibility = JsonAutoDetect.Visibility.NONE,
    getterVisibility = JsonAutoDetect.Visibility.NONE,
    isGetterVisibility = JsonAutoDetect.Visibility.NONE,
    creatorVisibility = JsonAutoDetect.Visibility.NONE
)
internal class Data {
    constructor(
        config: Config, event: SstEvent, models: Models.Data, dataLayer: Map<String, String?>
    ) : this(
        Settings(config),
        VirtualBrowser(Locale.getDefault(), config.clock().zone, config.virtualBrowser.page,  models),
        DataLayer(models, config.dataLayerName, dataLayer),
        listOf(Event(config, event))
    )

    @JsonCreator
    constructor(
        settings: Settings = Settings(),
        virtualBrowser: VirtualBrowser = VirtualBrowser(),
        dataLayer: DataLayer,
        events: List<Event> = emptyList()
    ) {
        this.settings = settings
        this.virtualBrowser = virtualBrowser
        this.dataLayer = dataLayer
        this.events = events
    }

    @JsonProperty
    val settings: Settings

    @JsonProperty
    val virtualBrowser: VirtualBrowser

    @JsonProperty
    val dataLayer: DataLayer

    @JsonProperty
    val events: List<Event>
}
